==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/BinaryAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociation;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.List;


public class BinaryAssociationSetImpl extends InstanceSet<BinaryAssociationSet,BinaryAssociation> implements BinaryAssociationSet {

    // attributes
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( BinaryAssociation binaryassociation : this ) binaryassociation.setDescrip( m_Descrip );
    }
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( BinaryAssociation binaryassociation : this ) binaryassociation.setAssoc_ID( ref_Assoc_ID );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( BinaryAssociation binaryassociation : this ) usecaseassociationset.add( binaryassociation.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public BinaryAssociation nullElement() {
        return BinaryAssociationImpl.EMPTY_BINARYASSOCIATION;
    }

    @Override
    public BinaryAssociationSet emptySet() {
      return new BinaryAssociationSetImpl();
    }

    @Override
    public BinaryAssociationSet value() {
        return this;
    }

    @Override
    public List<BinaryAssociation> elements() {
        return Arrays.asList(toArray(new BinaryAssociation[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/usecase/impl/BinaryAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.usecase.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociation;
import io.ciera.tool.sql.ooaofooa.usecase.BinaryAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.UseCaseAssociationSet;
import io.ciera.tool.sql.ooaofooa.usecase.impl.UseCaseAssociationSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BinaryAssociationSetImpl extends InstanceSet<BinaryAssociationSet,BinaryAssociation> implements BinaryAssociationSet {

    public BinaryAssociationSetImpl() {
    }

    public BinaryAssociationSetImpl(Comparator<? super BinaryAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setAssoc_ID( UniqueId ref_Assoc_ID ) throws XtumlException {
        for ( BinaryAssociation binaryassociation : this ) binaryassociation.setAssoc_ID( ref_Assoc_ID );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( BinaryAssociation binaryassociation : this ) binaryassociation.setDescrip( m_Descrip );
    }


    // selections
    @Override
    public UseCaseAssociationSet R1210_is_a_UseCaseAssociation() throws XtumlException {
        UseCaseAssociationSet usecaseassociationset = new UseCaseAssociationSetImpl();
        for ( BinaryAssociation binaryassociation : this ) usecaseassociationset.add( binaryassociation.R1210_is_a_UseCaseAssociation() );
        return usecaseassociationset;
    }


    @Override
    public BinaryAssociation nullElement() {
        return BinaryAssociationImpl.EMPTY_BINARYASSOCIATION;
    }

    @Override
    public BinaryAssociationSet emptySet() {
      return new BinaryAssociationSetImpl();
    }

    @Override
    public BinaryAssociationSet emptySet(Comparator<? super BinaryAssociation> comp) {
      return new BinaryAssociationSetImpl(comp);
    }

    @Override
    public BinaryAssociationSet value() {
        return this;
    }

    @Override
    public List<BinaryAssociation> elements() {
        return Arrays.asList(toArray(new BinaryAssociation[0]));
    }

}
